@@ -9,7 +9,9 @@
 
 #include <QObject>
 
-class Q_DECL_EXPORT ProcessRunner : public QObject
+#include <kcupslib_export.h>
+
+class KCUPSLIB_EXPORT ProcessRunner : public QObject
 {
     Q_OBJECT
 public:
@@ -18,7 +20,6 @@ public:
 public Q_SLOTS:
     void configurePrinter(const QString &printerName);
     void openPrintQueue(const QString &printerName);
-    void openPrintKCM();
 };
 
 #endif // PROCESS_RUNNER_H
